# Algorithm 2

In `src` you will find 2 folders:
1. `c1algo2`: The main module created for use by back end. After running `pip install c1algo2`, you can use our module as follows:
    ```
    from c1algo2.forecaster import forecast
    new_schedule = forecast(course_enrollment, program_enrollment, schedule)
    # store these in the db somehow
    ```

If you have any questions, please contact the Algorithm 2 team :)
